@@ -3,6 +3,8 @@ from .sessions import SQLiteSession, StringSession
 from .client import Client
 from .rubino import Rubino
 from . import types, utils, filters, exceptions, enums, sync
+from .bot import BotClient
+from . import bot
 
 __author__ = 'Rubigram Project'
-__version__ = '1.0.9'
+__version__ = '1.1.7'
