@@ -15,7 +15,8 @@ from .extras import Exctras
 from .gif import Gifs
 from .voice_chat import VoiceCall
 from .links import Links
-from .live import Lives
+from .lives import Lives
+from .bots import Bots
 
 
 class Methods(
@@ -35,6 +36,7 @@ class Methods(
     Gifs,
     VoiceCall,
     Links,
-    Lives
+    Lives,
+    Bots
 ):
     pass
