@@ -12,7 +12,8 @@ class SendVoice:
             voice: Union[Path, bytes],
             caption: Optional[str] = None,
             reply_to_message_id: Optional[str] = None,
-            auto_delete: Optional[int] = None, *args, **kwargs,
+            auto_delete: Optional[int] = None,
+            progress: bool = False, *args, **kwargs,
     ) -> "rubigram.types.Update":
         """
         Send a voice.
@@ -37,4 +38,4 @@ class SendVoice:
         #     if file_extension not in ['.ogg', '.opus']:
         #         raise ValueError(f"Unsupported file type for voice messages: {file_extension}")
 
-        return await self.send_message(object_guid=object_guid, text=caption, reply_to_message_id=reply_to_message_id, file_inline=voice, type='Voice', auto_delete=auto_delete, *args, **kwargs)
+        return await self.send_message(object_guid=object_guid, text=caption, reply_to_message_id=reply_to_message_id, file_inline=voice, type='Voice', auto_delete=auto_delete, progress=progress, *args, **kwargs)
