@@ -1,6 +1,6 @@
 
-import rubigram
 from typing import Union
+import rubigram
 
 
 class DeleteUserChat:
@@ -17,20 +17,20 @@ class DeleteUserChat:
     async def delete_user_chat(
             self: "rubigram.Client",
             user_guid: str,
-            last_deleted_message_id: Union[str, int],
+            last_message_id: Union[str, int],
     ) -> "rubigram.types.Update":
         """
         Delete a user chat.
 
         Args:
         - user_guid (str): The GUID of the user whose chat is to be deleted.
-        - last_deleted_message_id (Union[str, int]): The last deleted message ID.
+        - last_message_id (Union[str, int]): The last message ID.
 
         Returns:
         - The result of the user chat deletion.
         """
         return await self.builder('deleteUserChat',
                                   input={
-                                      'user_guid': user_guid,
-                                      'last_deleted_message_id': last_deleted_message_id,
+                                      'last_deleted_message_id': last_message_id,
+                                      'user_guid': user_guid
                                   })
