@@ -60,7 +60,6 @@ class Network:
             timeout=aiohttp.ClientTimeout(total=client.timeout)
         )
 
-        self.bot_api_url = f'https://messengerg2b1.iranlms.ir/v3/{client.bot_token}/' if client.bot_token else None
         self.api_url = None
         self.wss_url = None
         self.ws = None
@@ -92,7 +91,8 @@ class Network:
                     return True
             except Exception as e:
                 self.logger.warning(
-                    f"Error fetching Data Centers, attempt {attempt + 1}/{max_retries}: {e}")
+                    f"Error fetching Data Centers, attempt {
+                        attempt + 1}/{max_retries}: {e}")
                 if attempt < max_retries - 1:
                     await asyncio.sleep(backoff * (2 ** attempt))
         raise exceptions.NetworkError("Failed to fetch Data Centers")
@@ -117,7 +117,7 @@ class Network:
         while True:
             try:
                 async with self.session.post(
-                    "https://messengerg2c6.iranlms.ir",
+                    url,
                     json=data,
                     proxy=self.client.proxy
                 ) as response:
@@ -335,7 +335,8 @@ class Network:
                         return await response.json()
                 except Exception as e:
                     self.logger.warning(
-                        f"Error uploading chunk {part_number}، try {attempt + 1}/{max_retries}: {e}")
+                        f"Error uploading chunk {part_number}، try {
+                            attempt + 1}/{max_retries}: {e}")
                     if attempt < max_retries - 1:
                         await asyncio.sleep(backoff * (2 ** attempt))
                     else:
@@ -355,10 +356,9 @@ class Network:
                         continue
                     if callable(callback):
                         try:
-                            if inspect.iscoroutinefunction(callback):
-                                await callback(file_size, (index + 1) * chunk)
-                            else:
-                                callback(file_size, (index + 1) * chunk)
+                            res = callback(file_size, (index + 1) * chunk)
+                            if inspect.isawaitable(res):
+                                await res
                         except exceptions.CancelledError:
                             return None
                         except Exception as e:
@@ -375,10 +375,9 @@ class Network:
                     continue
                 if callable(callback):
                     try:
-                        if inspect.iscoroutinefunction(callback):
-                            await callback(file_size, (index + 1) * chunk)
-                        else:
-                            callback(file_size, (index + 1) * chunk)
+                        res = callback(file_size, (index + 1) * chunk)
+                        if inspect.isawaitable(res):
+                            await res
                     except exceptions.CancelledError:
                         return None
                     except Exception as e:
@@ -444,12 +443,14 @@ class Network:
                     async with session.post('/GetFile.ashx', headers=chunk_headers, proxy=self.client.proxy) as response:
                         if response.status != 200:
                             self.logger.warning(
-                                f"Download failed with status {response.status}")
+                                f"Download failed with status {
+                                    response.status}")
                             return b''
                         return await response.read()
                 except Exception as e:
                     self.logger.warning(
-                        f"Error downloading chunk {start_index}-{last_index}، تلاش {attempt + 1}/{max_retries}: {e}")
+                        f"Error downloading chunk {start_index}-{last_index}، تلاش {
+                            attempt + 1}/{max_retries}: {e}")
                     if attempt < max_retries - 1:
                         await asyncio.sleep(backoff * (2 ** attempt))
                     else:
